@@ -1,6 +1,6 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.0" language="fr">
+<TS version="2.1" language="fr">
 <context>
     <name>AuthDialog</name>
     <message>
@@ -39,14 +39,6 @@
         <source>Password: </source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Account locked %1 minutes due to %2 fail attempts</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Authentication failure,there are still %1 remaining opportunities</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Biometric Authentication</source>
         <translation type="unfinished"></translation>
@@ -205,7 +197,63 @@
     </message>
     <message>
         <source>SwitchUser</source>
-        <translation>Changer d&apos;utilisateur</translation>
+        <translation type="vanished">Changer d&apos;utilisateur</translation>
+    </message>
+</context>
+<context>
+    <name>PowerManager</name>
+    <message>
+        <source>SwitchUser</source>
+        <translation type="obsolete">Changer d&apos;utilisateur</translation>
+    </message>
+    <message>
+        <source>Lock Screen</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Switch User</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Log Out</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Restart</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Power Off</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>QObject</name>
+    <message>
+        <source>The screensaver is active.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>The screensaver is inactive.</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>Screensaver</name>
+    <message>
+        <source>Set as desktop wallpaper</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Automatic switching</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>SleepTime</name>
+    <message>
+        <source>You have rested:</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -226,5 +274,25 @@
         <source>activated by session idle signal</source>
         <translation>activé par le signal d&apos;inactivité de la session</translation>
     </message>
+    <message>
+        <source>Screensaver for ukui-screensaver</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>show on root window</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>show on window.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>window id</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>query the status of the screen saver</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
