@@ -21,6 +21,7 @@
 #include <QPixmap>
 #include <QHBoxLayout>
 #include <QPainter>
+#include <QPainterPath>
 #include <unistd.h>
 #include <pwd.h>
 #include <QBitmap>
@@ -80,6 +81,24 @@ void AuthDialog::stopAuth()
     }
 }
 
+QPixmap AuthDialog::PixmapToRound(const QPixmap &src, int radius)
+{
+    if (src.isNull()) {
+        return QPixmap();
+    }
+
+    QPixmap pixmapa(src);
+    QPixmap pixmap(radius*2,radius*2);
+    pixmap.fill(Qt::transparent);
+    QPainter painter(&pixmap);
+    painter.setRenderHints(QPainter::Antialiasing | QPainter::SmoothPixmapTransform);
+    QPainterPath path;
+    path.addEllipse(0, 0, radius*2, radius*2);
+    painter.setClipPath(path);
+    painter.drawPixmap(0, 0, radius*2, radius*2, pixmapa);
+    return pixmap;
+}
+
 void AuthDialog::initUI()
 {
     setFixedWidth(500);
@@ -91,11 +110,15 @@ void AuthDialog::initUI()
     m_faceLabel = new QLabel(m_userWidget);
     m_faceLabel->setObjectName(QStringLiteral("faceLabel"));
     m_faceLabel->setFocusPolicy(Qt::NoFocus);
-    QPixmap facePixmap(user.icon);
-
-    QPixmap pixMap= facePixmap.scaled(128,128, Qt::IgnoreAspectRatio, Qt::SmoothTransformation);
+    const QString SheetStyle = QString("border-radius: %1px;  border:0px   solid white;").arg(90*scale);
+    m_faceLabel->setStyleSheet(SheetStyle);
     m_faceLabel->setAlignment(Qt::AlignCenter);
-    m_faceLabel->setPixmap(pixMap);
+
+    QPixmap facePixmap(user.icon);
+    facePixmap = facePixmap.scaled(180*scale,180*scale, Qt::IgnoreAspectRatio, Qt::SmoothTransformation);
+    facePixmap = PixmapToRound(facePixmap, 90*scale);
+    m_faceLabel->setAlignment(Qt::AlignCenter);
+    m_faceLabel->setPixmap(facePixmap);
 
     /* 用户名 */
     m_nameLabel = new QLabel(m_userWidget);
@@ -104,6 +127,7 @@ void AuthDialog::initUI()
     m_nameLabel->setAlignment(Qt::AlignCenter);
     m_nameLabel->setText(user.realName.isEmpty() ? user.name : user.realName);
 
+
     /* 密码框所在窗口 */
     m_passwdWidget = new QWidget(this);
     m_passwdWidget->setObjectName(QStringLiteral("passwordWidget"));
@@ -118,6 +142,7 @@ void AuthDialog::initUI()
 //    m_passwordEdit->hide(); //收到请求密码的prompt才显示出来
     m_passwordEdit->setEnabled(false);
     m_passwordEdit->setType(QLineEdit::Password);
+    setFocusProxy(m_passwordEdit);
     connect(m_passwordEdit, SIGNAL(clicked(const QString&)),
             this, SLOT(onRespond(const QString&)));
 
@@ -134,16 +159,29 @@ void AuthDialog::resizeEvent(QResizeEvent *)
 
 void AuthDialog::setChildrenGeometry()
 {
+    if(scale < 0.5)
+        setFixedWidth(500);
+
     // 用户信息显示位置
-    m_userWidget->setGeometry(0, (height() - 240 - 150) / 2,
-                              width(), 240);
-    m_faceLabel->setGeometry((width() - 128) / 2, 0, 128, 128);
-    m_nameLabel->setGeometry(0, m_faceLabel->geometry().bottom() + 25,
+    m_userWidget->setGeometry(0, 0,
+                              width(), 292*scale);
+    
+    const QString SheetStyle = QString("border-radius: %1px;  border:0px   solid white;").arg(90*scale);
+    m_faceLabel->setStyleSheet(SheetStyle);
+
+    QPixmap facePixmap(user.icon);
+    facePixmap = facePixmap.scaled(180*scale,180*scale, Qt::IgnoreAspectRatio, Qt::SmoothTransformation);
+    facePixmap = PixmapToRound(facePixmap, 90*scale);
+    m_faceLabel->setAlignment(Qt::AlignCenter);
+    m_faceLabel->setPixmap(facePixmap);
+
+    m_faceLabel->setGeometry((width() - 180*scale) / 2, 0, 180*scale, 180*scale);
+    m_nameLabel->setGeometry(0, m_faceLabel->geometry().bottom() + 25*scale,
                              width(), 40);
 
     // 密码框和提示信息显示位置
-    m_passwdWidget->setGeometry(0, m_userWidget->geometry().bottom(), width(), 150);
-    m_passwordEdit->setGeometry((m_passwdWidget->width() - 400)/2, 0, 400, 40);
+    m_passwdWidget->setGeometry(0, m_nameLabel->geometry().bottom() + 45*scale, width(), 150);
+    m_passwordEdit->setGeometry((m_passwdWidget->width() - 300)/2, 0, 300, 34);
     m_messageLabel->setGeometry((m_passwdWidget->width() - 600)/2,
                                 m_passwordEdit->geometry().bottom() + 25,
                                 600, 20);
@@ -209,24 +247,7 @@ void AuthDialog::onAuthComplete()
 
     if(auth->isAuthenticated())
     {
-        if(pam_tally_is_enbled() && !pam_tally_is_canUnlock())
-        {
-            pam_tally_add_failed();
-            int unlock_time = pam_tally_unlock_time();
-            int failed_count = pam_tally_failed_count();
-            int unlock_time_min = unlock_time /60;
-    //        sprintf(msg, "您已经输错%d次，将锁定账户%d分钟", failed_count, unlock_time_min);
-    //        onShowMessage(tr(msg), Auth::MessageTypeError);
-            int deny = pam_tally_deny();
-            onShowMessage(tr("Account locked %1 minutes due to %2 fail attempts").arg(unlock_time_min).arg(deny), Auth::MessageTypeError);
-            authMode = PASSWORD;
-            startAuth();
-        }
-        else
-        {
-            pam_tally_clear_failed();
             Q_EMIT authenticateCompete(true);
-        }
     }
     else
     {
@@ -234,24 +255,6 @@ void AuthDialog::onAuthComplete()
                       Auth::MessageTypeError);
         //认证失败，重新认证
 
-        if(pam_tally_is_enbled())
-        {
-            pam_tally_add_failed();
-            int deny = pam_tally_deny();
-            int failed_count = pam_tally_failed_count();
-            int unlock_time = pam_tally_unlock_time();
-            int unlock_time_min = unlock_time / 60;
-
-            if (failed_count >= 0 && failed_count < deny)
-            {
-                onShowMessage(tr("Authentication failure,there are still %1 remaining opportunities").arg(deny-failed_count), Auth::MessageTypeError);
-            }
-            else if (failed_count >= deny)
-            {
-                onShowMessage(tr("Account locked %1 minutes due to %2 fail attempts").arg(unlock_time_min).arg(deny), Auth::MessageTypeError);
-            }
-        }
-
         authMode = PASSWORD;
         startAuth();
     }
@@ -369,6 +372,7 @@ void AuthDialog::performBiometricAuth()
     m_biometricAuthWidget->startAuth(m_deviceInfo, user.uid);
 
     showBiometricAuthWidget();
+
 }
 
 void AuthDialog::skipBiometricAuth()
@@ -412,6 +416,7 @@ void AuthDialog::initBiometricButtonWidget()
 
     m_biometricButton = new QPushButton(m_buttonsWidget);
     m_biometricButton->setObjectName(QStringLiteral("biometricButton"));
+    m_biometricButton->setIcon(QIcon(":/image/assets/bio-login.png"));
     m_biometricButton->setText(tr("Biometric Authentication"));
     m_biometricButton->setSizePolicy(sizePolicy);
     m_biometricButton->setVisible(false);
@@ -424,6 +429,7 @@ void AuthDialog::initBiometricButtonWidget()
 
     m_passwordButton = new QPushButton(m_buttonsWidget);
     m_passwordButton->setObjectName(QStringLiteral("passwordButton"));
+    m_passwordButton->setIcon(QIcon(":/image/assets/password-login.png"));
     m_passwordButton->setText(tr("Password Authentication"));
     fm = QFontMetrics(m_passwordButton->font(), m_passwordButton);
     width = fm.width(m_passwordButton->text());
@@ -478,7 +484,7 @@ void AuthDialog::setBiometricWidgetGeometry()
     if(m_biometricDevicesWidget)
     {
         m_biometricDevicesWidget->setGeometry((width() - m_biometricDevicesWidget->width()) / 2,
-                                              (height() - m_biometricDevicesWidget->height()) / 2,
+                                              0,
                                               m_biometricDevicesWidget->width(),
                                               m_biometricDevicesWidget->height());
     }
@@ -488,7 +494,7 @@ void AuthDialog::setBiometricButtonWidgetGeometry()
 {
     if(m_buttonsWidget)
     {
-        m_buttonsWidget->setGeometry(0, height() - m_buttonsWidget->height() - 100,
+        m_buttonsWidget->setGeometry(0, height() - m_buttonsWidget->height() - y() - 100,
                                      width(), m_buttonsWidget->height());
     }
 }
