@@ -42,7 +42,7 @@ class BiometricProxy;
 class BiometricAuthWidget;
 class BiometricDevicesWidget;
 
-
+extern float scale;
 class AuthDialog : public QWidget
 {
     Q_OBJECT
@@ -68,6 +68,7 @@ private:
     void showPasswordAuthWidget();
     void showBiometricAuthWidget();
     void showBiometricDeviceWidget();
+    QPixmap PixmapToRound(const QPixmap &src, int radius);
 
 private Q_SLOTS:
     void onShowMessage(const QString &message, Auth::MessageType type);
