@@ -41,13 +41,15 @@ public Q_SLOTS:
      * Lock the screen
      */
     void Lock();
-
+    bool GetLockState();
+    void SetLockState();
     void onSessionIdleReceived();
-
+    void onShowScreensaver();
     void onNameLost(const QString&);
 
 private:
     bool checkExistChild();
+    bool lockState;
 
 private:
     QProcess process;
