@@ -23,12 +23,15 @@
 #endif
 
 #include <QWidget>
+#include <QResizeEvent>
+
 
 namespace Ui {
 class LockWidget;
 }
 
 class VirtualKeyboard;
+class PowerManager;
 class AuthDialog;
 class Users;
 class UserItem;
@@ -42,7 +45,6 @@ class LockWidget : public QWidget
 public:
     explicit LockWidget(QWidget *parent = 0);
     ~LockWidget();
-    void resizeEvent(QResizeEvent *event);
     void closeEvent(QCloseEvent *event);
     void startAuth();
     void stopAuth();
@@ -61,14 +63,18 @@ private Q_SLOTS:
     void onUserDeleted(const UserItem &user);
     void onUserMenuTrigged(QAction *action);
     void showVirtualKeyboard();
+    void showPowerManager();
+    void switchToGreeter();
 
 protected:
      bool eventFilter(QObject *obj, QEvent *event);
+     void resizeEvent(QResizeEvent *event);
 
 private:
     Ui::LockWidget      *ui;
     AuthDialog          *authDialog;
     VirtualKeyboard     *vKeyboard;
+    PowerManager        *powermanager;
     QTimer              *timer;
     QMenu               *usersMenu;
     Users               *users;
