@@ -24,7 +24,7 @@
 #include <QKeyEvent>
 #include <QtX11Extras/QX11Info>
 #include <X11/Xlib.h>
-
+#include <sys/prctl.h>
 ScreenSaverWidget::ScreenSaverWidget(ScreenSaver *screensaver, QWidget *parent)
     : QWidget(parent),
       timer(nullptr),
@@ -33,7 +33,6 @@ ScreenSaverWidget::ScreenSaverWidget(ScreenSaver *screensaver, QWidget *parent)
       closing(false)
 {
     qDebug() << "ScreenSaverWidget::ScreenSaverWidget";
-    qDebug() << *screensaver;
     setMouseTracking(true);
     setFocus();
     this->installEventFilter(this);
@@ -42,7 +41,6 @@ ScreenSaverWidget::ScreenSaverWidget(ScreenSaver *screensaver, QWidget *parent)
     plt.setBrush(QPalette::Window, Qt::black);
     setPalette(plt);
     setAutoFillBackground(true);
-
     switch(screensaver->mode) {
     case SAVER_RANDOM:
     case SAVER_SINGLE:
@@ -63,6 +61,9 @@ ScreenSaverWidget::ScreenSaverWidget(ScreenSaver *screensaver, QWidget *parent)
                 this, &ScreenSaverWidget::onBackgroundChanged);
         break;
     }
+    case SAVER_DEFAULE:
+        embedXScreensaver(screensaver->path);
+        break;
     }
     show();
 }
@@ -132,7 +133,6 @@ bool ScreenSaverWidget::eventFilter(QObject *obj, QEvent *event)
     if(event->type() == 23)
     {
         XSetInputFocus(QX11Info::display(),this->winId(),RevertToParent,CurrentTime);
-
     }
     return false;
 }
@@ -144,6 +144,7 @@ void ScreenSaverWidget::embedXScreensaver(const QString &path)
     char widStr[20] = {0};
     snprintf(widStr, sizeof(widStr), "%lu", wid);
     if((xscreensaverPid = fork()) == 0) {
+	prctl(PR_SET_PDEATHSIG, SIGHUP);
         execl(path.toStdString().c_str(), "xscreensaver", "-window-id", widStr, (char*)0);
         qWarning() << "exec " << path << "failed";
     }
