@@ -23,13 +23,14 @@
 #include <QCommandLineOption>
 #include <QDateTime>
 #include <QDebug>
+#include <QDesktopWidget>
 #include <QDBusInterface>
 #include <signal.h>
 #include <unistd.h>
 #include <fcntl.h>
 #include <sys/types.h>
 #include <QProcess>
-
+#include <X11/Xlib.h>
 #include "fullbackgroundwidget.h"
 
 #define CACHE_DIR "/.cache/ukui-screensaver/"
@@ -111,15 +112,27 @@ void checkIsRunning()
     }
 }
 
+void handler(int signum)
+{
+    qApp->quit();
+}
+
 #define WORKING_DIRECTORY "/usr/share/ukui-screensaver"
 int main(int argc, char *argv[])
 {
     checkIsRunning();
     checkIslivecd();
+	
+#if(QT_VERSION>=QT_VERSION_CHECK(5,6,0))
+    QCoreApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
+    QCoreApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
+#endif
+
+    qunsetenv("QT_IM_MODULE");
+ //   signal(SIGTERM,handler);
     QApplication a(argc, argv);
     QApplication::setSetuidAllowed(true);
 
-
     //命令行参数解析
     QCommandLineParser parser;
     parser.setApplicationDescription(QCoreApplication::translate("main", "Dialog for the ukui ScreenSaver."));
@@ -130,37 +143,15 @@ int main(int argc, char *argv[])
                                   QCoreApplication::translate("main", "lock the screen immediately"));
     QCommandLineOption sessionIdleOption(QStringLiteral("session-idle"),
                                        QCoreApplication::translate("main", "activated by session idle signal"));
-    parser.addOptions({lockOption, sessionIdleOption});
+    QCommandLineOption screensaverOption(QStringLiteral("screensaver"),
+                                       QCoreApplication::translate("main", "lock the screen and show screensaver immediately"));
+    parser.addOptions({lockOption, sessionIdleOption , screensaverOption});
     parser.process(a);
 
-    if(!parser.isSet(sessionIdleOption) && !parser.isSet(lockOption))
+    if(!parser.isSet(sessionIdleOption) && !parser.isSet(lockOption) && !parser.isSet(screensaverOption))
     {
         return 0;
     }
-    else
-    {
-        if(parser.isSet(lockOption))
-        {
-            if("fcitx" == qgetenv("QT_IM_MODULE"))
-            {
-                qunsetenv("QT_IM_MODULE");
-//                QProcess * process = new QProcess;//不阻塞
-//                process->start("/usr/bin/ukui-screensaver-dialog --lock");
-//                exit(EXIT_SUCCESS);
-            }
-        }
-
-        if(parser.isSet(sessionIdleOption))
-        {
-            if("fcitx" == qgetenv("QT_IM_MODULE"))
-            {
-                qunsetenv("QT_IM_MODULE");
-//                QProcess * process = new QProcess;//不阻塞
-//                process->start("/usr/bin/ukui-screensaver-dialog --session-idle");
-//                exit(EXIT_SUCCESS);
-            }
-        }
-    }
 
     qInstallMessageHandler(messageOutput);
 
@@ -190,6 +181,14 @@ int main(int argc, char *argv[])
         if(window->onSessionStatusChanged(SESSION_IDLE) == -1)
 	    return 0;
     }
+ 
+    if(parser.isSet(screensaverOption))
+    {
+    	window->onScreensaver();
+    }
+    
+    window->show();
+    window->activateWindow();
 	
     QString username = getenv("USER");
     int uid = getuid();
@@ -200,10 +199,6 @@ int main(int argc, char *argv[])
                                                    window);
 
     QDBusMessage msg = interface->call(QStringLiteral("SetPropOfContainer"),username, uid, "is_kydroid_on_focus", "0");
-
-    window->show();
-    window->activateWindow();
-
     return a.exec();
 }
 
@@ -215,8 +210,8 @@ static void messageOutput(QtMsgType type, const QMessageLogContext &context, con
     QByteArray localMsg = msg.toLocal8Bit();
 
     QString filePath(context.file);
-    int seprator = filePath.lastIndexOf('/');
-    QString fileName = filePath.right(filePath.length() - seprator - 1);
+    int separator = filePath.lastIndexOf('/');
+    QString fileName = filePath.right(filePath.length() - separator - 1);
     const char *file = fileName.toLocal8Bit().data();
 
     switch(type) {
